@@ -17,15 +17,14 @@
 
 #include "qtmultimediaoutputbackend.h"
 #include <QDir>
-#include <QUrl>
 #include <QMediaPlayer>
+#include <QUrl>
 
 QtMultimediaOutputBackend::QtMultimediaOutputBackend(QObject *parent)
     : OutputBackendInterface(parent)
     , m_player(new QMediaPlayer)
 {
-    connect(m_player, &QMediaPlayer::stateChanged,
-            this, &QtMultimediaOutputBackend::stateChanged);
+    connect(m_player, &QMediaPlayer::stateChanged, this, &QtMultimediaOutputBackend::stateChanged);
 }
 
 QtMultimediaOutputBackend::~QtMultimediaOutputBackend()
@@ -40,23 +39,23 @@ void QtMultimediaOutputBackend::setUri(const QString &uri)
 
 int QtMultimediaOutputBackend::volume() const
 {
-    return m_player->volume(); //TODO check if this is really a cubic value
+    return m_player->volume(); // TODO check if this is really a cubic value
 }
 
 void QtMultimediaOutputBackend::setVolume(int volume)
 {
-    m_player->setVolume(volume); //TODO check if value is cubic
+    m_player->setVolume(volume); // TODO check if value is cubic
 }
 
 OutputDeviceController::State QtMultimediaOutputBackend::state() const
 {
     switch (m_player->state()) {
-    case QMediaPlayer::StoppedState:
-        return OutputDeviceController::StoppedState;
-    case QMediaPlayer::PlayingState:
-        return OutputDeviceController::PlayingState;
-    case QMediaPlayer::PausedState:
-        return OutputDeviceController::PausedState;
+        case QMediaPlayer::StoppedState:
+            return OutputDeviceController::StoppedState;
+        case QMediaPlayer::PlayingState:
+            return OutputDeviceController::PlayingState;
+        case QMediaPlayer::PausedState:
+            return OutputDeviceController::PausedState;
     }
     Q_UNREACHABLE();
     return OutputDeviceController::StoppedState;
